@@ -8,7 +8,7 @@ KCU__IN_SUBSETS = {
     "SHORT_CRESTED_STRUCTURES": [4],
     "2D_OPEN_WATER_OBSTACLES": [101],
     "2D_VERTICAL_INFILTRATION": [150],
-    "2D_GROUNDWATER": [-150],
+    "2D_GROUNDWATER": [-150, 600, 700, 800, 900],
     "ACTIVE_BREACH": [56],
     "POTENTIAL_BREACH": [55],
 }
