@@ -1,14 +1,8 @@
-# -*- coding: utf-8 -*-
 """help text functions for threedigrid management commands"""
-from __future__ import unicode_literals
-from __future__ import print_function
-from __future__ import division
-from __future__ import absolute_import
 
 from collections import OrderedDict
 
 from threedigrid.admin.gridadmin import GridH5Admin
-import six
 
 
 def model_overview(grid_file):
@@ -25,24 +19,26 @@ def model_overview(grid_file):
     """
 
     grid = GridH5Admin(grid_file)
-    _attrs = OrderedDict([
-        ('model_slug', ''),
-        ('threedicore_version', ''),
-        ('threedi_version', ''),
-        ('has_1d', ''),
-        ('has_2d', ''),
-        ('has_groundwater', ''),
-        ('has_levees', ''),
-        ('has_breaches', ''),
-        ('has_pumpstations', ''),
-    ])
+    _attrs = OrderedDict(
+        [
+            ("model_slug", ""),
+            ("threedicore_version", ""),
+            ("threedi_version", ""),
+            ("has_1d", ""),
+            ("has_2d", ""),
+            ("has_groundwater", ""),
+            ("has_levees", ""),
+            ("has_breaches", ""),
+            ("has_pumpstations", ""),
+        ]
+    )
 
-    for k in six.iterkeys(_attrs):
+    for k in _attrs.keys():
         if not hasattr(grid, k):
             continue
         attr = getattr(grid, k)
         if attr is None:
             continue
-        _attrs[k] = '{:24} {}'.format(k.replace('_', ' ') + ':', attr)
+        _attrs[k] = "{:24} {}".format(k.replace("_", " ") + ":", attr)
 
-    return '\n'.join((v for v in _attrs.values() if v != '')) + '\n'
+    return "\n".join(v for v in _attrs.values() if v != "") + "\n"
